<?php

namespace Drupal\eth_fundraiser\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class EthFundraiserForm.
 */
class EthFundraiserForm extends ConfigFormBase {

  /**
   * GuzzleHttp\ClientInterface definition.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->httpClient = $container->get('http_client');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'eth_fundraiser.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'eth_fundraiser_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

	$config = $this->config('eth_fundraiser.settings');
    $form['markup1'] = [
      '#type' => 'markup',
      '#markup' => '
        <div class="btn-group">
          <a href="https://martelus.club" target="_blank" class="btn-martelus-club">Get Club Access</a>
          <a href="https://martelus.net" target="_blank" class="btn-martelus-io">Create an Account</a> 
        </div>
        <p class="welcome-message">
          The Eth Fundraiser Component allows you to raise funds through the ethereum blockchain. It also allows you to customize the component to match your site theme.<br>
          If you find that you need additional functionality there is a club member version available which offers multiple currencies, chain selection, token selection, additional wallet detection, installation assistance, technical support and more.
        </p>
      '
    ];

    $form['address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Ethereum Address'),
      '#placeholder' => '0x',
      '#description' => $this->t('Use your ethereum address to use the component to send funds to your address.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('address'),
    ];

    $form['position'] = [
      '#type' => 'select',
      '#title' => $this->t('Banner Position'),
      '#description' => $this->t('Select a position for the banner to appear.'),
      '#options' => ['none' => $this->t('None'),'left' => $this->t('Left'),'center' => $this->t('Center'), 'right' => $this->t('Right')],
      '#size' => 0,
      '#default_value' => $config->get('position'),
    ];

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Banner Text"),
      '#description' => $this->t('Change the banner title text.'),
      '#size' => 64,
      '#default_value' => $config->get("title"),
    ];

    $form['markup2'] = [
      '#type' => 'markup',
      '#markup' => '
        <div class="row">
      '
    ];

    
    
    $form['markup3'] = [
      '#type' => 'markup',
      '#markup' => '
        <div class="column">
      '
    ];
    $form['titleColor'] = [
      '#type' => 'color',
      '#title' => $this->t("Banner Color Text"),
      '#description' => $this->t('Change the banner title color text.'),
      '#size' => 7,
      '#default_value' => $config->get("titleColor"),
    ];

    $form['svgCircle'] = [
      '#type' => 'color',
      '#title' => $this->t('SVG Circle Background'),
      '#description' => $this->t("Change the circle background color"),
      '#size' => 7,
      '#default_value' => $config->get('svgCircle')
    ];

    $form['svgEthIcon'] = [
      '#type' => 'color',
      '#title' => $this->t('SVG Eth Icon Color'),
      '#description' => $this->t("Change the eth icon color"),
      '#size' => 7,
      '#default_value' => $config->get('svgEthIcon')
    ];

    $form['bannerBackground'] = [
      '#type' => 'color',
      '#title' => $this->t("Banner Background"),
      '#description' => $this->t('Change the banner background.'),
      '#size' => 7,
      '#default_value' => $config->get("bannerBackground"),
    ];
    $form['markup4'] = [
      '#type' => 'markup',
      '#markup' => '
        </div>
      '
    ]; 
    $form['markup5'] = [
      '#type' => 'markup',
      '#markup' => '
        <div class="column">
      '
    ];
    $form['buttonBackground'] = [
      '#type' => 'color',
      '#title' => $this->t("Button Background"),
      '#description' => $this->t('Change the button background.'),
      '#size' => 7,
      '#default_value' => $config->get("buttonBackground"),
    ];

    $form['buttonText'] = [
      '#type' => 'color',
      '#title' => $this->t("Button Text Color"),
      '#description' => $this->t('Change the button text color.'),
      '#size' => 7,
      '#default_value' => $config->get("buttonText"),
    ];

    $form['closeBtnColor'] = [
      '#type' => 'color',
      '#title' => $this->t("Close Button Color"),
      '#description' => $this->t('Change the close button color.'),
      '#size' => 7,
      '#default_value' => $config->get("closeBtnColor"),
    ];

     $form['ethPriceColor'] = [
      '#type' => 'color',
      '#title' => $this->t("Eth Price Color"),
      '#description' => $this->t('Change eth price text color.'),
      '#size' => 7,
      '#default_value' => $config->get("ethPriceColor"),
    ];
    $form['markup6'] = [
      '#type' => 'markup',
      '#markup' => '
        </div>
      '
    ]; 
    $form['markup7'] = [
      '#type' => 'markup',
      '#markup' => '
        </div>
      '
    ]; 
    
    $form['markup8'] = [
      '#type' => 'markup',
      '#markup' => '
      <div>
        <h3>Attention</h3>
        <p>Remember after saving your changes to clear cache.</p>
      </div>'
    ];
   
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('eth_fundraiser.settings')
      ->set('address', $form_state->getValue('address'))
      ->set('position', $form_state->getValue('position'))
      ->set('title', $form_state->getValue('title')) 
      
      ->set('titleColor', $form_state->getValue('titleColor'))
      
      ->set('bannerBackground', $form_state->getValue('bannerBackground'))
      ->set('buttonBackground', $form_state->getValue('buttonBackground'))
      ->set('buttonText', $form_state->getValue('buttonText'))
      ->set('svgCircle', $form_state->getValue('svgCircle'))
      ->set('svgEthIcon', $form_state->getValue('svgEthIcon'))
 
      ->set('closeBtnColor', $form_state->getValue('closeBtnColor'))
      ->set('ethPriceColor', $form_state->getValue('ethPriceColor'))

      ->save();
    \Drupal::service('cache.render')->invalidateAll();
  }

}

