<?php

namespace Drupal\eth_fundraiser\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Config\ConfigFactory;
/**
 * Provides a 'EthFundraiserBlock' block.
 *
 * @Block(
 *  id = "eth_fundraiser_block",
 *  admin_label = @Translation("EthFundraiser"),
 * )
 */

class EthFundraiserBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Defines the configuration object factory.
   *
   * @var Drupal\Core\Config\ConfigFactory
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactory $config) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config;
  }
  
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->config->get('eth_fundraiser.settings');

    $build = [];
    $build['#theme'] = 'eth_fundraiser_block';

    $items = array();
    $items['address'] = $config->get('address');
    $items['position'] = $config->get('position');

    $items['title'] = $config->get('title');
    $items['titleColor'] = $config->get('titleColor');

    $items['bannerBackground'] = $config->get('bannerBackground');
    $items['buttonBackground'] = $config->get('buttonBackground');
    $items['buttonText'] = $config->get('buttonText');
    $items['svgCircle'] = $config->get('svgCircle');
    $items['svgEthIcon'] = $config->get('svgEthIcon');
    $items['closeBtnColor'] = $config->get('closeBtnColor');
    $items['ethPriceColor'] = $config->get('ethPriceColor');
    $build['#content'] = $items;

    return $build;
  }
}

